@@ -1,18 +1,7 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8 -
 #
-# Copyright (c) 2008-2009 Benoit Chesneau <benoitc@e-engura.com>
-#
-# Permission to use, copy, modify, and distribute this software for any
-# purpose with or without fee is hereby granted, provided that the above
-# copyright notice and this permission notice appear in all copies.
-#
-# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+# This file is part of couchdbkit released under the MIT license. 
+# See the NOTICE for more information.
 
 """
 Client implementation for CouchDB access. It allows you to manage a CouchDB
@@ -745,7 +734,8 @@ class Database(object):
                 headers=headers, rev=doc1['_rev']).json_body
 
         if res['ok']:
-            doc1.update({ '_rev': res['rev']})
+            new_doc = self.get(doc1['_id'], rev=res['rev'])
+            doc.update(new_doc)
         return res['ok']
 
     def delete_attachment(self, doc, name):
@@ -761,7 +751,8 @@ class Database(object):
 
         res = self.res(docid).delete(name, rev=doc['_rev']).json_body
         if res['ok']:
-            doc.update({ '_rev': res['rev']})
+            new_doc = self.get(doc['_id'], rev=res['rev'])
+            doc.update(new_doc)
         return res['ok']
 
 
