@@ -1,18 +1,7 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8 -
 #
-# Copyright (c) 2008-2009 Benoit Chesneau <benoitc@e-engura.com> 
-#
-# Permission to use, copy, modify, and distribute this software for any
-# purpose with or without fee is hereby granted, provided that the above
-# copyright notice and this permission notice appear in all copies.
-#
-# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+# This file is part of couchdbkit released under the MIT license. 
+# See the NOTICE for more information.
 
 import anyjson
 import asyncore
@@ -124,7 +113,8 @@ class Consumer(object):
             chunked = False
         
         try:
-            change_handler = continuous_changes_handler(resp, self.callbacks, chunked)
+            change_handler = continuous_changes_handler(resp, 
+                                            self.callbacks, chunked)
             asyncore.loop()
         except:
             self.close()
@@ -133,7 +123,7 @@ class Consumer(object):
     def close(self):
         if self._resp is None:
             return
-        self._resp.close()
+        self._resp.http_client.maybe_close()
         self._resp = None
         
         
@@ -143,8 +133,8 @@ class continuous_changes_handler(asynchat.async_chat):
         self.resp = resp
         self.callbacks = callbacks
         self.chunked = chunked
-        self.buf = [resp._body.buf]
-        sock = resp.http_client.socket
+        self.buf = [resp._body.tmp.read()]
+        sock = resp.http_client._sock
         asynchat.async_chat.__init__(self, sock=sock)
         if self.chunked:
             self.set_terminator("\r\n")
@@ -153,7 +143,7 @@ class continuous_changes_handler(asynchat.async_chat):
         self.chunk_left = False
         
     def handle_close(self):
-        self.resp.close()
+        self.resp.http_client.maybe_close()
         
     def collect_incoming_data(self, data):
         if self.chunked:
