@@ -1,18 +1,7 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8 -
 #
-# Copyright (c) 2008-2009 Benoit Chesneau <benoitc@e-engura.com> 
-#
-# Permission to use, copy, modify, and distribute this software for any
-# purpose with or without fee is hereby granted, provided that the above
-# copyright notice and this permission notice appear in all copies.
-#
-# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+# This file is part of couchdbkit released under the MIT license. 
+# See the NOTICE for more information.
 
 """ 
 couchdb.resource
@@ -78,9 +67,7 @@ class CouchdbResource(Resource):
 
         @param uri: str, full uri to the server.
         """
-        
-        response_class = client_opts.get('response_class', CouchDBResponse)
-        client_opts['response_class'] = response_class
+        client_opts['response_class'] = CouchDBResponse
         
         Resource.__init__(self, uri=uri, **client_opts)
         self.safe = ":/%"
@@ -164,10 +151,8 @@ class CouchdbResource(Resource):
                         response=e.response)
             else:
                 raise
-        except RequestError, e:
+        except Exception, e:
             raise RequestFailed(str(e))
-        except:
-            raise
         
         return resp
 
