@@ -1,18 +1,7 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8 -
 #
-# Copyright (c) 2008-2009 Benoit Chesneau <benoitc@e-engura.com>
-#
-# Permission to use, copy, modify, and distribute this software for any
-# purpose with or without fee is hereby granted, provided that the above
-# copyright notice and this permission notice appear in all copies.
-#
-# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+# This file is part of couchdbkit released under the MIT license. 
+# See the NOTICE for more information.
 
 """ module that provides a Document object that allows you
 to map CouchDB document in Python statically, dynamically or both
@@ -237,7 +226,7 @@ class DocumentSchema(object):
         """
         if self._dynamic_properties and key in self._dynamic_properties:
             return self._dynamic_properties[key]
-        elif key == "_id" or key == "_rev":
+        elif key  in ('_id', '_rev', '_attachments'):
             return self._doc.get(key)
         return getattr(super(DocumentSchema, self), key)
 
@@ -439,7 +428,7 @@ class DocumentBase(DocumentSchema):
         doc = self.to_json()
         self._db.save_doc(doc, **params)
         if '_id' in doc and '_rev' in doc:
-            self._doc.update({'_id': doc['_id'], '_rev': doc['_rev']})
+            self._doc.update(doc)
         elif '_id' in doc:
             self._doc.update({'_id': doc['_id']})
 
